@@ -4,8 +4,8 @@
 
 ;; Author: Alvaro Ramirez https://xenodium.com
 ;; URL: https://github.com/xenodium/shell-maker
-;; Package-Version: 20251112.1702
-;; Package-Revision: a83134afe540
+;; Package-Version: 20260104.1718
+;; Package-Revision: 53742d44b48a
 ;; Package-Requires: ((emacs "27.1"))
 
 ;; This package is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@
 
 ;;; Code:
 
-(defconst shell-maker-version "0.84.1")
+(defconst shell-maker-version "0.84.5")
 
 (require 'comint)
 (require 'goto-addr)
@@ -102,6 +102,13 @@ For example:
   :type 'directory
   :group 'shell-maker)
 
+(defcustom shell-maker-curl-executable "curl"
+  "Path to the curl executable.
+Can be a simple command name like \"curl\" if it's in PATH,
+or an absolute path like \"/usr/local/bin/curl\"."
+  :type 'string
+  :group 'shell-maker)
+
 (defcustom shell-maker-forget-file-after-clear nil
   "If non-nil, reset file path after clear command."
   :type 'boolean
@@ -154,7 +161,7 @@ For example:
   :parent comint-mode-map
   :doc "Base keymap for `shell-maker' based modes."
   "S-<return>" #'newline
-  "C-x C-s" #'shell-maker-save-session-transcript
+  "<remap> <save-buffer>" #'shell-maker-save-session-transcript
   "C-M-h" #'shell-maker-mark-output)
 
 (defun shell-maker-start (config &optional no-focus welcome-function new-session buffer-name mode-line-name)
@@ -1016,7 +1023,7 @@ and TIMEOUT: defaults to 600ms."
       (with-temp-file data-file
         (setq-local coding-system-for-write encoding)
         (insert (shell-maker--json-encode data))))
-    (append (list "curl" url
+    (append (list shell-maker-curl-executable url
                   "--fail-with-body"
                   "--no-progress-meter"
                   "-m" (number-to-string timeout))
@@ -1273,7 +1280,7 @@ returned list is of the form:
 
 (defun shell-maker--curl-version-supported ()
   "Return t if curl version is 7.76 or newer, nil otherwise."
-  (let ((curl-version-string (shell-command-to-string (concat "curl --version "))))
+  (let ((curl-version-string (shell-command-to-string (concat shell-maker-curl-executable " --version "))))
     (when (string-match "\\([0-9]+\\.[0-9]+\\.[0-9]+\\)" curl-version-string)
       (let ((version (match-string 1 curl-version-string)))
         (version<= "7.76" version)))))
@@ -1531,7 +1538,6 @@ If BACKWARDS is non-nil, move backwards."
   "Extract all commands and respective output in TEXT with PROMPT-REGEXP.
 
 Returns a list of (command . output) cons."
-  (setq text (substring-no-properties text))
   (let ((result))
     (mapc (lambda (item)
             (let* ((values (split-string item "<shell-maker-end-of-prompt>"))
